import React, { memo } from "react";
import classNames from "classnames";
import { styled, Tooltip } from "@material-ui/core";
import stringToSequence from "../../string-to-sequence.js";
var SequenceItemContainer = styled("span")(function (_ref) {
  var color = _ref.color,
      relationshipsOn = _ref.relationshipsOn;
  return {
    display: "inline-flex",
    cursor: "pointer",
    backgroundColor: color,
    color: "#fff",
    padding: 4,
    margin: 4,
    marginBottom: relationshipsOn ? 64 : 4,
    paddingLeft: 10,
    paddingRight: 10,
    borderRadius: 4,
    userSelect: "none",
    boxSizing: "border-box",
    "&.unlabeled": {
      color: "#333",
      paddingTop: 4,
      paddingBottom: 4,
      paddingLeft: 2,
      paddingRight: 2,
      ".notSpace:hover": {
        paddingTop: 2,
        paddingBottom: 2,
        paddingLeft: 0,
        paddingRight: 0,
        border: "2px dashed #ccc"
      }
    }
  };
});
var XContainer = styled("div")({
  display: "inline-flex",
  cursor: "pointer",
  alignSelf: "center",
  fontSize: 11,
  width: 18,
  height: 18,
  alignItems: "center",
  justifyContent: "center",
  marginLeft: 4,
  borderRadius: 9,
  color: "#fff",
  backgroundColor: "rgba(0,0,0,0.2)"
});
export var SequenceItem = function SequenceItem(_ref2) {
  var textId = _ref2.textId,
      text = _ref2.text,
      label = _ref2.label,
      color = _ref2.color,
      sequenceItemIndex = _ref2.sequenceItemIndex,
      sequenceItemPositionsRef = _ref2.sequenceItemPositionsRef,
      relationshipsOn = _ref2.relationshipsOn,
      createRelationshipsMode = _ref2.createRelationshipsMode,
      onChangeFirstSequenceItem = _ref2.onChangeFirstSequenceItem,
      onChangeSecondSequenceItem = _ref2.onChangeSecondSequenceItem,
      onCreateEmptyRelationship = _ref2.onCreateEmptyRelationship,
      onChangeHighlightedRange = _ref2.onChangeHighlightedRange,
      firstSequenceItem = _ref2.firstSequenceItem,
      secondSequenceItem = _ref2.secondSequenceItem,
      mouseDown = _ref2.mouseDown,
      firstSelected = _ref2.firstSelected,
      lastSelected = _ref2.lastSelected,
      colorLabelMap = _ref2.colorLabelMap,
      isHighlighted = _ref2.isHighlighted,
      onRemoveLabel = _ref2.onRemoveLabel,
      showDelete = _ref2.showDelete;
  return /*#__PURE__*/React.createElement(SequenceItemContainer, {
    key: textId || sequenceItemIndex,
    ref: function ref(elm) {
      if (!elm) return;
      sequenceItemPositionsRef.current[textId] = {
        offset: {
          left: elm.offsetLeft,
          top: elm.offsetTop,
          width: elm.offsetWidth,
          height: elm.offsetHeight
        }
      };
    },
    relationshipsOn: relationshipsOn,
    onMouseUp: function onMouseUp(e) {
      if (!createRelationshipsMode) return;

      if (!secondSequenceItem) {
        onChangeFirstSequenceItem(null);
        onChangeSecondSequenceItem(null);
        onCreateEmptyRelationship([firstSequenceItem, textId]);
      } else {
        onChangeFirstSequenceItem(null);
        onChangeSecondSequenceItem(null);
      }
    },
    onMouseDown: function onMouseDown() {
      if (createRelationshipsMode) {
        if (!firstSequenceItem) {
          onChangeFirstSequenceItem(textId);
        }
      } else {
        if (label) return;
        onChangeHighlightedRange([sequenceItemIndex, sequenceItemIndex]);
      }
    },
    onMouseMove: function onMouseMove() {
      if (!mouseDown) return;

      if (!createRelationshipsMode) {
        if (label) return;

        if (sequenceItemIndex !== lastSelected) {
          onChangeHighlightedRange([firstSelected === null ? sequenceItemIndex : firstSelected, sequenceItemIndex]);
        }
      }
    },
    className: classNames(label ? "label" : "unlabeled", text.trim().length > 0 && "notSpace"),
    color: label ? color || "#333" : !createRelationshipsMode && text !== " " && isHighlighted ? "#ccc" : "inherit"
  }, label ? /*#__PURE__*/React.createElement(Tooltip, {
    title: label,
    placement: "bottom"
  }, /*#__PURE__*/React.createElement("div", null, text)) : /*#__PURE__*/React.createElement("div", null, text), label && showDelete && !createRelationshipsMode && /*#__PURE__*/React.createElement(XContainer, {
    onClick: function onClick(e) {
      e.stopPropagation();
      onRemoveLabel(sequenceItemIndex);
    }
  }, /*#__PURE__*/React.createElement("span", null, "\u2716")));
};
export default memo(SequenceItem);