// @flow

import React, { useMemo } from "react"
import Box from "@material-ui/core/Box"
import Typography from "@material-ui/core/Typography"
import Workspace from "react-material-workspace-layout/Workspace"
import PrevIcon from "@material-ui/icons/KeyboardArrowLeft"
import NextIcon from "@material-ui/icons/KeyboardArrowRight"
import SaveIcon from '@material-ui/icons/Save';
import { grey } from "@material-ui/core/colors"

export default ({
  children,
  onNext,
  onPrev,
  onFinish,
  currentSampleIndex = 0,
  numberOfSamples = 1,
  titleContent,
  onClickHeaderItem,
  hideHeader
}: any) => {
  const headerItems = useMemo(
    () =>
      [
        (currentSampleIndex > 0 || onPrev) && {
          name: "上一个",
          icon: <PrevIcon />,
          onClick: onPrev
        },
        (numberOfSamples > currentSampleIndex + 1 || onNext) && {
          name: "下一个",
          icon: <NextIcon />,
          onClick: onNext
        },
        onFinish && {
          name: "保存",
          icon: <SaveIcon />,
          onClick: onFinish
        }
      ].filter(Boolean),
    [currentSampleIndex, numberOfSamples]
  )
  return (
    <Workspace
      hideHeader={hideHeader}
      headerLeftSide={
        titleContent === undefined ? (
          <Box paddingLeft={2} fontWeight="bold">
            <Typography>
              Sample {currentSampleIndex + 1} / {numberOfSamples}
            </Typography>
          </Box>
        ) : (
            <div style={{
              fontWeight: "bold",
              color: grey[700],
              paddingLeft: 16,
            }}>{titleContent}</div>
          )
      }
      onClickHeaderItem={onClickHeaderItem}
      headerItems={headerItems}
      iconSidebarItems={[]}
      rightSidebarItems={[]}
    >
      <Box padding={2}>{children}</Box>
    </Workspace>
  )
}
